Module flatlog

This is the main module that exposes custom formatting to the OTP logger library (part of the kernel application since OTP-21).

Description

This is the main module that exposes custom formatting to the OTP logger library (part of the kernel application since OTP-21).

The module honors the standard configuration of the kernel's default logger formatter regarding: max depth, templates.

Function Index

format/2
format_msg/2
to_string/2

Function Details

format/2

format(LogEvent, Config) -> unicode:chardata()

format_msg/2

format_msg(Data, Config) -> any()

to_string/2

to_string(X, C) -> any()


Generated by EDoc